@@ -10,7 +10,7 @@ use Moo;
 with "Dancer2::Plugin::Auth::Extensible::Role::Provider";
 use namespace::clean;
 
-our $VERSION = '0.601';
+our $VERSION = '0.602';
 
 =head1 NAME 
 
@@ -55,6 +55,9 @@ details, but it could be as simple as, e.g.:
             realms:
                 users:
                     provider: 'DBIC'
+                    users_resultset: 'User'
+                    roles_resultset: Role
+                    user_roles_resultset: UserRole
         DBIC:
             default:
                 dsn: dbi:mysql:database=mydb;host=localhost
@@ -254,10 +257,83 @@ to configure these, and they will be generated internally automatically.
 
 =head1 SUGGESTED SCHEMA
 
-Please see Schema1 in the tests directory for a suggested schema.
+If you use a schema similar to the examples provided here, you should need minimal 
+configuration to get this authentication provider to work for you.  The examples 
+given here should be MySQL-compatible; minimal changes should be required to use 
+them with other database engines.
 
-If producing a schema from scratch, it is recommended that the default
-resultset and column names are used, as per the default configuration.
+=head2 user Table
+
+You'll need a table to store user accounts in, of course. A suggestion is something 
+like:
+
+     CREATE TABLE user (
+         id int(11) NOT NULL AUTO_INCREMENT,
+		 username varchar(32) NOT NULL,
+         password varchar(40) DEFAULT NULL,
+         name varchar(128) DEFAULT NULL,
+         email varchar(255) DEFAULT NULL,
+         deleted tinyint(1) NOT NULL DEFAULT '0',
+         lastlogin datetime DEFAULT NULL,
+         pw_changed datetime DEFAULT NULL,
+         pw_reset_code varchar(255) DEFAULT NULL,
+         PRIMARY KEY (id)
+     );
+
+All columns from the users table will be returned by the C<logged_in_user> keyword 
+for your convenience.
+
+=head2 role Table
+
+You'll need a table to store a list of available groups in.
+
+	 CREATE TABLE role (
+         id int(11) NOT NULL AUTO_INCREMENT,
+         role varchar(32) NOT NULL,
+         PRIMARY KEY (id)
+     );
+
+=head2 user_role Table
+
+Also requred is a table mapping the users to the roles.
+
+     CREATE TABLE user_role (
+         user_id int(11) NOT NULL,
+         role_id int(11) NOT NULL,
+         PRIMARY KEY (user_id, role_id),
+         FOREIGN KEY (user_id) REFERENCES user(id),
+         FOREIGN KEY (role_id) REFERENCES role(id)
+     );
+
+=head1 SEE ALSO
+
+L<Dancer2::Plugin::Auth::Extensible>
+
+L<Dancer2::Plugin::DBIC>
+
+L<Dancer2::Plugin::Auth::Extensible::Provider::Database>
+
+=head1 AUTHORS
+
+Andrew Beverley C<< <a.beverley@ctrlo.com> >>
+
+Rewrite for Plugin2:
+
+Peter Mottram, C<< <peter@sysnix.com> >>
+
+=head1 CONTRIBUTORS
+
+Ben Kaufman (whosgonna)
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright 2015-2016 Andrew Beverley
+
+This program is free software; you can redistribute it and/or modify it
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
+
+See http://dev.perl.org/licenses/ for more information.
 
 =cut
 
